polyfemos.back.seismic.scanner — polyfemos 0.3.29 documentation

# polyfemos.back.seismic.scanner

Scans available mseed files.

copyright

  2019, University of Oulu, Sodankyla Geophysical Observatory

license

  GNU Lesser General Public License v3.0 or later (https://spdx.org/licenses/LGPL-3.0-or-later.html)

Public Functions

`polyfemos.back.seismic.scanner.` `data_coverage_image`(flags, starttime, endtime, network_code, station_codes, channel_codes, datafilepathfunc, outfilepathfunc)

  Creates data coverage images using `Scanner`.

  The available seismic data is scanned between times `starttime` and `endtime`. All channel and station combinations are included in the scan (`channel_codes` and `station_codes`).

  Parameters

    - flags (dict) – Flag variables from `Interpreter`

    - startime (`Ordinal`) –

    - endtime (`Ordinal`) –

    - network_code (str) – Network code as a string, e.g. “FN”

    - station_codes (list) – list of string consisting of station codes, e.g. `["MSF", "SGF", ...]`.

    - channel_codes (list) – list of string consisting of channel codes, e.g. `["HHZ", "HHE", ...]`.

    - datafilepathfunc (func) – A function returning filepaths to be included in the scan.

    - outfilepathfunc (func) – If the `outfilepathfunc` returns different filepaths with changing stations or channels etc., separate scanner plots are created with each different filepath.

`polyfemos.back.seismic.scanner.` `get_data_coverage_figure`(station_ids, channel_codes, startdate, enddate, datafilepathfunc)
  Parameters

    - station_ids (list) – station ids as a list of strings

    - channel_codes (list) – data channel codes as a list of strings

    - startdate (`UTCDateTime`) – scanning startdate

    - enddate (`UTCDateTime`) – scanning enddate

    - filepathfunc (func) – A dynamic filepath, wildcards can be used since `glob()` is use to process filepaths after the arguments are filled in.

  Return type

    `Figure`

  Returns

    scanner plot

`polyfemos.back.seismic.scanner.` `null_figure`(*args, **kwargs)
  Return type

    `Figure`

  Returns

    Empty figure